provides :php_application

# Support dry-run
#
def why_run_supported?; true; end

# Do not support inline resources due to pool having to notify php-fpm
#
#use_inline_resources

action :deploy do
  new_resource = @new_resource

  deploy_packages new_resource.packages
  deploy_pears new_resource.pears
  if new_resource.deployment and not new_resource.deployment.empty?
    deploy_deployment new_resource.deployment
  end
end

action :enable do
  run_action_and_track :create do
    deploy_pool(new_resource.pool)
  end if new_resource.pool and not new_resource.pool.empty?
end

action :disable do
  run_action_and_track :disable do
    deploy_pool(new_resource.pool)
  end if new_resource.pool and not new_resource.pool.empty?
end

private 

def resource_short_name
  @resource_short_name ||= ::File.basename(new_resource.name)
end

def deploy_packages(packages)
  packages.each do |name, hash|
    next if node[:php][:packages].include?(name)
    hash = {} if hash.nil? or hash == true

    exec_action = hash[:action] || hash["action"] || :install
    run_action_and_track exec_action do
      package name do
        hash.each do |key,value|
          send(key, value)
        end
        notifies :reload, "service[php5-fpm]"
      end
    end
  end
end

def deploy_pears(pears)
  pears.each do |name, hash|
    next if node[:php][:pear_packages].keys.include?(name)
    hash = {} if hash.nil? or hash == true
    exec_action = hash[:action] || hash["action"] || :install
    run_action_and_track exec_action do
      php_pear name do
        hash.each do |key,value|
          send(key, value)
        end
        notifies :reload, "service[php5-fpm]"
      end
    end
  end
end

def deploy_deployment(hash)
  new_resource = @new_resource

  run_action_and_track :deploy do
    php_deployment new_resource.path do
      hash.each do |key, value|
        send(key, value)
      end
    end
  end
end

def deploy_pool(hash)
  new_resource = @new_resource

  php_pool resource_short_name do
    hash.each do |key, value|
      send(key, value)
    end
  end
end

def run_action_and_track(action, &block)
  res = block.call
  res.action(action)

  if res.updated_by_last_action?
    new_resource.updated_by_last_action(true)
  end

  res
end

