
provides :php_deployment

require "chef/mixin/from_file"
include Chef::Mixin::FromFile

# Support dry-run
#
def why_run_supported?; true; end

use_inline_resources

action :deploy do
  new_resource = @new_resource

  install_ssh
  deploy_git
  bind_callbacks
end

private 

def resource_short_name
  @resource_short_name ||= ::File.basename(new_resource.name)
end

# deploy oauth token to ~/.netrc to enable passwordless git cloning
#
def install_ssh
  return unless new_resource.ssh_key

  short_name = resource_short_name
  home = node[:etc][:passwd][new_resource.user][:dir]

  directory "#{home}/.ssh" do
    owner new_resource.user
    group new_resource.group
    mode 0700
  end

  file "#{home}/.ssh/#{short_name}.rsa" do
    owner new_resource.user
    group new_resource.group
    mode 0400
    sensitive true
    content new_resource.ssh_key
  end

  file "#{home}/.ssh/#{short_name}.cmd" do
    owner new_resource.user
    group new_resource.group
    mode 0500
    content "#!/bin/sh\nexec \
    /usr/bin/ssh \
      -i #{home}/.ssh/#{short_name}.rsa \
      -o \"StrictHostKeyChecking=no\" \
      \"$@\"
    "
  end
end

# deploy code base
#
def deploy_git
  new_resource = @new_resource
  short_name = resource_short_name
  home = node[:etc][:passwd][new_resource.user][:dir]

  directory new_resource.path do
    user  new_resource.user
    group new_resource.group
    recursive true
  end

  git new_resource.path do
    repository  new_resource.url
    revision    new_resource.revision
    user        new_resource.user
    group       new_resource.group
    if new_resource.ssh_key
      ssh_wrapper "#{home}/.ssh/#{short_name}.cmd"
    end
    enable_submodules true
    action      :sync
  end
end

def bind_callbacks
  callback(:after_deploy, new_resource.after_deploy)
end

# optional callbacks
#
def callback(name, code=nil)
  case code
  when String
    run_callback_from_string(code)
  when Array
    code.each { |arg| callback(name, arg) }
  end
end

def run_callback_from_string(callback_string)
  new_resource = @new_resource
  execute callback_string do
    cwd new_resource.path
    subscribes :run, "git[#{new_resource.path}]"
    action :nothing
  end
end

# 
#

