
def initialize(*args)
  super *args
  #
  # As a convenience, provide a mechanism to ensure that nginx_file
  # always reloads nginx upon change without having to manually duplicate
  # the call each time. Tunable via the timing attribute.
  #
  notifies :reload, "service[php5-fpm]"
end

actions :create, :delete, :disable
default_action :create

provides :php_pool
resource_name :php_pool

attribute :listen,
  kind_of: String,
  required: true

attribute :listen_mode,
  kind_of: String,
  default: "660"

attribute :listen_user,
  kind_of: String,
  default: lazy { |r| r.user }

attribute  :listen_group,
  kind_of: String,
  default: lazy{ |r| r.group }

attribute :backlog,
  kind_of: Numeric,
  default: 65535

attribute :allowed_clients,
  kind_of: Array,
  default: []

attribute :user,
  kind_of: String,
  default: node[:php][:fpm_user]

attribute :group,
  kind_of: String,
  default: node[:php][:fpm_group]

attribute :process_manager,
  kind_of: String,
  required: true

attribute :process_idle_timeout,
  kind_of: String,
  default: "10s"

attribute :max_children,
  kind_of: Integer,
  required: true

attribute :start_servers,
  kind_of: Integer

attribute :min_spare_servers,
  kind_of: Integer

attribute :max_spare_servers,
  kind_of: Integer

attribute :max_requets,
  kind_of: Integer,
  default: 0

attribute :catch_workers_output,
  kind_of: String,
  default: 'yes'

attribute :status_path,
  kind_of: String,
  default: nil

attribute :ping_path,
  kind_of: String,
  default: nil

attribute :security_limit_extensions,
  kind_of: Array,
  default: ['.php']

attribute :request_terminate_timeout,
  kind_of: Integer,
  default: 0

attribute :env_variables,
  kind_of: Hash,
  default: {}

attribute :php_admin_variables,
  kind_of: Hash,
  default: {}

attribute :php_admin_flags,
  kind_of: Hash,
  default: {}

def path
  file_name = name.include?(".conf") ? name : "#{name}.conf"
  "#{node['php']['fpm_pooldir']}/#{file_name}"
end

def variables
  {
    name: name,
    listen: listen,
    listen_mode: listen_mode,
    listen_user: listen_user,
    listen_group: listen_group,
    mode: listen_mode,
    backlog: backlog,
    allowed_clients: allowed_clients,
    user: user,
    group: group,
    process_manager: process_manager,
    process_idle_timeout: process_idle_timeout,
    max_children: max_children,
    start_servers: start_servers,
    min_spare_servers: min_spare_servers,
    max_spare_servers: max_spare_servers,
    max_requets: max_requets,
    catch_workers_output: catch_workers_output,
    status_path: status_path,
    ping_path: ping_path,
    security_limit_extensions: security_limit_extensions,
    request_terminate_timeout: request_terminate_timeout,
    env_variables: env_variables,
    php_admin_variables: php_admin_variables,
    php_admin_flags: php_admin_flags
  }
end

